DogSerializerException class abstract
Exception thrown when a DogConverter fails to convert a value.
- Implemented types
- Implementers
Constructors
- DogSerializerException({required String message, DogConverter? converter, DogStructure? structure, Object? cause, StackTrace? innerStackTrace})
-
Creates a new DogSerializerException with the given attributes.
factory
Properties
- cause → Object?
-
The original exception that has been caught by the DogConverter.
May be null if no nested exception was involved.
no setter
- converter → DogConverter?
-
The DogConverter that failed the conversion. May be null if no converter
was involved, for example when serializing native values.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerStackTrace → StackTrace?
-
The stacktrace of the original exception.
May be null if no nested exception was involved.
no setter
- message → String
-
The message of this exception.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structure → DogStructure?
-
The DogStructure that failed the conversion.
May be null if no structure was involved.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited